<?php

/**
 * This file contains \QUI\Tags\Controls\SiteTags
 */

namespace QUI\Tags\Controls;

use QUI;

/**
 * tag list control
 *
 * @author www.pcsg.de (Henning Leutz)
 */
class SiteTags extends QUI\Control
{
    /**
     * constructor
     *
     * @param array $attributes
     */
    public function __construct($attributes = [])
    {
        // defaults
        $this->setAttributes([
            'hideTitle' => true
        ]);

        parent::__construct($attributes);

        $this->addCSSFile(
            \dirname(__FILE__).'/SiteTags.css'
        );

        $this->setAttribute('class', 'quiqqer-tags-list grid-100 grid-parent');
    }

    /**
     * (non-PHPdoc)
     *
     * @see \QUI\Control::create()
     */
    public function getBody()
    {
        /* @var $Site QUI\Projects\Site */
        $Engine = QUI::getTemplateManager()->getEngine();
        $Site   = $this->getAttribute('Site');

        if (!$Site) {
            $Site = QUI::getRewrite()->getSite();
        }

        $Project = $Site->getProject();
        $Tags    = new QUI\Tags\Manager($Project);
        $tags    = $Site->getAttribute('quiqqer.tags.tagList');
        $tagList = [];

        if (\is_array($tags)) {
            foreach ($tags as $tag) {
                try {
                    $tagList[] = $Tags->get($tag);
                } catch (QUI\Exception $Exception) {
                }
            }
        }

        $Engine->assign([
            'Project'    => $Project,
            'Site'       => $Site,
            'Locale'     => QUI::getLocale(),
            'TagManager' => new QUI\Tags\Manager($Project),
            'this'       => $this,
            'tagList'    => $tagList,
            'SearchSite' => $this->getSearchSite()
        ]);

        return $Engine->fetch(\dirname(__FILE__).'/SiteTags.html');
    }

    /**
     * Return the global tag search site
     *
     * @return mixed|QUI\Projects\Site|QUI\Projects\Site\Edit
     */
    protected function getSearchSite()
    {
        $Site = $this->getAttribute('Site');

        if (!$Site) {
            $Site = QUI::getRewrite()->getSite();
        }

        $Project   = $Site->getProject();
        $cacheName = $Project->getName().'/'.$Project->getLang().'/sites/quiqqer/tags:types/tag-search';

        try {
            return $Project->get(
                QUI\Cache\Manager::get($cacheName)
            );
        } catch (QUI\Exception $Exception) {
        }

        $language     = $Project->getLang();
        $tagSearchIds = $Project->getConfig('tags.tagSearchId');

        if ($tagSearchIds) {
            $tagSearchIds = \json_decode($tagSearchIds, true);

            if ($tagSearchIds[$language]) {
                try {
                    $Site = QUI\Projects\Site\Utils::getSiteByLink($tagSearchIds[$language]);

                    QUI\Cache\Manager::set($cacheName, $Site->getId());

                    return $Site;
                } catch (QUI\Exception $Exception) {
                }
            }
        }

        $result = $Project->getSites([
            'where' => [
                'type' => 'quiqqer/tags:types/tag-search'
            ],
            'limit' => 1
        ]);

        if (isset($result[0])) {
            QUI\Cache\Manager::set($cacheName, $result[0]->getId());

            return $result[0];
        }

        return $Site;
    }
}
